=====
Usage
=====

.. warning::
   Documentation is under construction. For now please refer to the
   ``examples/`` directory in the source distribution.

There are two layers that you might be interested in.

You can either use the existing recipes, most notably, the Command recipe. This
is the best way to get started with Guacamole and get advantage of the code
that is here already.

The second layer is useful once you start to feel comfortable with the code and
want to get more features or perhaps convert your custom code over to work with
Guacamole.

Both layers are documented below but first read the philosophy statement.

.. toctree::
   :maxdepth: 2

   philosophy
   concepts
   recipes
